==> kui-web-terminal-container-v2.2.1-2.tar.gz: package/mdist/controller/kubectl/delete.js <==
/*
 * Copyright 2019 IBM Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { crudFlags } from './flags';
import { doExecWithStatus } from './exec';
import commandPrefix from '../command-prefix';
import { FinalState } from '../../lib/model/states';
import { isUsage, doHelp } from '../../lib/util/help';
/**
 * Prepare the command line for delete: by default, apparently,
 * kubernetes treats finalizers as synchronous, and --wait defaults to
 * true
 *
 */
function prepareArgsForDelete(args) {
    if (!Object.prototype.hasOwnProperty.call(args.parsedOptions, 'wait')) {
        return args.command + ' --wait=false';
    }
    else {
        return args.command;
    }
}
export const doDelete = (command = 'kubectl') => (args) => __awaiter(void 0, void 0, void 0, function* () {
    if (isUsage(args)) {
        return doHelp(command, args, prepareArgsForDelete);
    }
    else {
        return doExecWithStatus('delete', FinalState.OfflineLike, command, prepareArgsForDelete)(args);
    }
});
export default (registrar) => {
    registrar.listen(`/${commandPrefix}/kubectl/delete`, doDelete(), crudFlags);
    registrar.listen(`/${commandPrefix}/k/delete`, doDelete(), crudFlags);
};
//# sourceMappingURL=delete.js.map

==> kui-web-terminal-container-v2.3.3-6.tar.gz: package/mdist/controller/kubectl/delete.js <==
/*
 * Copyright 2019 The Kubernetes Authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import defaultFlags from './flags';
import { doExecWithStatus } from './exec';
import deleteDirect from '../client/direct/delete';
import { FinalState } from '../../lib/model/states';
import { isUsage, doHelp } from '../../lib/util/help';
/**
 * Prepare the command line for delete: by default, apparently,
 * kubernetes treats finalizers as synchronous, and --wait defaults to
 * true
 *
 */
function prepareArgsForDelete(args) {
    if (!Object.prototype.hasOwnProperty.call(args.parsedOptions, 'wait')) {
        return args.command + ' --wait=false';
    }
    else {
        return args.command;
    }
}
export const doDelete = (command = 'kubectl') => (args) => __awaiter(void 0, void 0, void 0, function* () {
    if (isUsage(args)) {
        return doHelp(command, args, prepareArgsForDelete);
    }
    else {
        try {
            const directResponse = yield deleteDirect(args);
            if (directResponse) {
                return directResponse;
            }
        }
        catch (err) {
            if (err.code === 404) {
                throw err;
            }
            else {
                console.error('Error in direct delete. Falling back to CLI delete.', err.code, err);
            }
        }
        return doExecWithStatus('delete', FinalState.OfflineLike, command, prepareArgsForDelete)(args);
    }
});
export default (registrar) => {
    registrar.listen('/kubectl/delete', doDelete(), defaultFlags);
    registrar.listen('/k/delete', doDelete(), defaultFlags);
};
//# sourceMappingURL=delete.js.map
